<?php
/**
 * 自定义语义问答库，你应自定义尽可能多的问答，推荐至少一千条
 * 避免使用默认问答库，格式须符合PHP语法要求（如有英文单引号须在前加“\"转义）
 * 否则程序将出错，应尽可能定义计算机理解不了，而人类很容易的问题
 * 定义时需注意避免出现多个答案，比如问题：
 *   '能载很多飞机的用于军事的大船叫什么？'
 * 回答可能是“航母”、“航空母舰”，因此必须通过提示对问题进行限制，纠正为：
 *   '能载很多飞机的用于军事的大船叫什么？4字'
 * 系统使用“==”和答案做比较，如出现二义性将带来很不好的用户体验
 *
 * by:yunke
 * email: phpworld@qq.com
 * time:20191028
 */
$semanticList = [
    ['著名诗句“面朝大海”的下一句？', '春暖花开'],
    ['中国历史上的西楚霸王是谁？', '项羽'],
    ['新中国成立于哪一年？4位数字', '1949'],
    ['淘宝网主要创始人是哪一位？', '马云'],
    ['巴蜀大地指的是哪一个省？两个字', '四川'],
    ['现中国的首都是？两个字', '北京'],
    ['一代天骄是指谁？4个字', '成吉思汗'],
    ['“只识弯弓射大雕”是谁说的？', '毛泽东'],
    ['相对论是谁提出的？', '爱因斯坦'],
    ['86版西游记美猴王的扮演者是？', '六小龄童'],
    ['能载很多飞机的用于军事的大船叫什么？4字', '航空母舰'],
    ['羊毛和棉花做的衣服，通常谁更贵？', '羊毛'],
    ['手机膜三十五元，壳贰拾壹元，一共多少钱？数字作答', '56'],

    ['华为公司创始人全名？', '任正非'],
    ['改革开放总设计师邓小平先生是哪省人？', '四川'],
    ['中国历史上汉朝开国皇帝全名的拼音？', 'liubang'],
    ['植物光合作用吸收二氧化碳并释放供人类呼吸的什么？两字', '氧气'],
    ['三国演义中蜀国第一谋士？', '诸葛亮'],
    ['谁挟天子以令诸侯？', '曹操'],
    ['八戒的师傅的第三徒弟叫什么？3字', '沙和尚'],
    ['“人之初”后面三个字？', '性本善'],
    ['誉为计算机界最高荣誉的奖项以谁名字命名？两字', '图灵'],
    ['梨是水果吗？回答是或不是', '是'],
    ['喜欢的反义词？', '讨厌'],
    ['八十年代四大天王中姓刘的是谁', '刘德华'],
    ['“世界那么大，我想去看看”这句话最后一字的拼音？', 'kan'],
    ['中国著名陶瓷盛产地？3字', '景德镇'],
    ['四川省会？两字', '成都'],
    ['“你”的英文单词？小写', 'you'],
    ['锄禾日当午，汗滴XX土，这里XX是什么', '禾下'],
    ['牛顿是哪国人？', '英国'],
    ['希特勒所在党派名字？两字', '纳粹'],
    ['日本汽车巨头有两田，本田外是？', '丰田'],
    ['通讯工具qq属于哪个公司？两字', '腾讯'],
    ['互联网三字的拼音首字母？小写', 'hlw'],
    ['番茄又叫？三字', '西红柿'],
    ['“爱”用英语怎么说？4个小写字母', 'love'],
    ['shenzhen挨着香港，输入拼音对应的汉字', '深圳'],
    ['鲨鱼的拼音？', 'shayu'],
    ['诗人李白的性别？一个字', '男'],
    ['中国历史上唯一的女皇帝', '武则天'],
    ['李世民是哪个朝代的人？一个字', '唐'],
    ['汽车品牌BYD的中文名', '比亚迪'],
    ['太阳地球月亮谁最小', '月亮'],
    ['太阳地球月亮谁最热', '太阳'],
    ['太阳地球月亮谁最适合人类生存', '地球'],
    ['52-3等于', '49'],
    ['挂耳旁加可是什么字', '阿'],
    ['water中文意思？一个字', '水'],
    ['请输入三个中文句号', '。。。'],
    ['请输入两个井号', '##'],
    ['农村过年会放一种很响的东西，是什么', '鞭炮'],
    ['可以指方向的仪器叫？中国四大发明之一', '指南针'],
    ['012346789缺了哪个数字', '5'],
    ['3乘以7是多少', '21'],
    ['茶是一种yinliao,拼音是指？', '饮料'],
    ['水加很多糖会是什么味道？一个字', '甜'],
    ['甜的反义词', '苦'],
    ['谚语“水至清则无X”？一个字', '鱼'],
    ['酸菜配鱼就像番茄炒XX？', '鸡蛋'],
    ['2的英语单词？小写', 'two'],
    ['自由女神像是哪个国家的', '美国'],
    ['埃菲尔铁搭位于哪个城市？两字', '巴黎'],
    ['天安门上所挂照片是谁', '毛泽东'],
    ['武侠天龙八部中段誉的大哥是？', '乔峰'],
    ['新白娘子传奇女主叫什么？', '白素贞'],
    ['新白娘子传奇男主叫什么？', '许仙'],
    ['红楼梦中林黛玉和谁至死也没有在一起？', '贾宝玉'],
    ['经典四大名著《石头记》又叫？', '红楼梦'],
    ['梁山好汉八十万禁军教头是？两字', '林冲'],
    ['倒拔杨柳的花和尚是？', '鲁智深'],
    ['秦始皇的名字？两字', '嬴政'],
    ['赵匡胤建立了什么朝代？一个字', '宋'],
    ['中国封建制最后一个朝代？一个字', '清'],
    ['三个木组成的汉字？', '森'],
    ['上下两个口组成的汉字', '吕'],
    ['led和白炽灯哪个较省电？', 'led'],
    ['孙悟空有多少种变？数字', '72'],
    ['中国两大河，除了长江还有？', '黄河'],
    ['陆地上跑的最快的动物？一个字', '豹'],
    ['花椒的味道？一个字', '麻'],
    ['爸爸的爸爸叫什么？', '爷爷'],
    ['只许州官放火的下一句？', '不许百姓点灯'],
    ['三个臭皮匠赛过？', '诸葛亮'],
    ['柠檬的味道？一个字', '酸'],
    ['欲穷千里目的下一句？', '更上一层楼'],
    ['滚滚长江东逝水是哪部著名影视的主题曲', '三国演义'],
    ['你挑着担，我牵着马，是哪部家喻户晓的影视主题曲？', '西游记'],
    ['著名忠臣岳飞背上刺着的四个字？', '精忠报国'],
    ['千里走单骑的名将是？三国刘备二弟', '关羽'],
    ['时间的英语单词？', 'time'],
    ['彩云之南指的是中国哪个省？两字', '云南'],
    ['茅台酒和老干妈产于哪个省？两字', '贵州'],
    ['和沙县小吃齐名的是？XXX面', '兰州拉面'],
    ['广东汽车牌照以哪个字开始？', '粤'],
    ['拉萨有个著名宫殿叫什么？', '布达拉宫'],
    ['包大人手下的第一高手？被皇上封为御猫，两字', '展昭'],
    ['3+2-5+6=？数字作答', '6'],
    ['中国报警电话是多少？输入数字', '110'],
    ['中国火警电话是多少？输入数字', '119'],
    ['云客两字的拼音？小写不要空格', 'yunke'],
    
];